kOT_sim_OT
kOT_sim_OT(work_dir, NN, nGENE, nPATH, SCEN, ncores = 1)Nothing. Rds files are created within the simulation ROKET directory.
A full path to create "sim_ROKET" and subdirectories
A positive integer for sample size
A positive integer for number of genes to simulate
A positive integer for number of pathways to simulate
An integer taking values 1, 2, 3, or 4
A positive integer specifying the number of cores/threads to use for optimal transport calculations