Runs balanced or unbalanced optimal transport on two input vectors
run_myOT(
XX,
YY,
COST,
EPS,
LAMBDA1,
LAMBDA2 = NULL,
balance = FALSE,
conv = 1e-05,
max_iter = 3000,
verbose = TRUE,
show_iter = 50
)A R list containing the optimal transport matrix and associated distance metric.
A numeric vector of positive masses
A numeric vector of positive masses
A numeric matrix of non-negative values
representing the costs to transport masses between
features of XX and YY. The rows of COST
and features of XX need to be aligned.
The columns of COST and features of YY
need to be aligned.
A positive numeric value representing the tuning parameter for entropic regularization.
A non-negative numeric value representing
the tuning parameter penalizing the distance between XX
and the row sums of the optimal transport matrix.
A non-negative numeric value representing
the tuning parameter penalizing the distance between YY
and the column sums of the optimal transport matrix.
Boolean set to TRUE to run balanced
optimal transport regardless of LAMDA1 and LAMBDA2.
Otherwise run unbalanced optimal transport.
A positive numeric value to determine
algorithmic convergence. The default value is 1e-5.
A positive integer denoting the maximum iterations to run the algorithm.
Boolean value to display verbose function output.
A positive integer to display iteration details
at multiples of show_iter but only if verbose = TRUE.