run_myOTs
run_myOTs(
ZZ,
COST,
EPS,
LAMBDA1,
LAMBDA2 = NULL,
balance,
conv = 1e-05,
max_iter = 3000,
ncores = 1,
verbose = TRUE,
show_iter = 50
)A R numeric matrix of pairwise distances.
A numeric matrix of non-negative mass to transport. Rows correspond to features (e.g. genes) and columns correspond to samples or individuals. Each column must have strictly positive mass
A numeric square matrix of non-negative values representing the non-negative costs to transport masses between pairs of features
A positive numeric value representing the tuning parameter for entropic regularization.
A non-negative numeric value representing
the tuning parameter penalizing the distance between XX
and the row sums of the optimal transport matrix.
A non-negative numeric value representing
the tuning parameter penalizing the distance between YY
and the column sums of the optimal transport matrix.
Boolean set to TRUE to run balanced
optimal transport regardless of LAMDA1 and LAMBDA2.
Otherwise run unbalanced optimal transport.
A positive numeric value to determine
algorithmic convergence. The default value is 1e-5.
A positive integer denoting the maximum iterations to run the algorithm.
A positive integer for the number of cores/threads to reduce computational runtime when running for loops
Boolean value to display verbose function output.
A positive integer to display iteration details
at multiples of show_iter but only if verbose = TRUE.